Learn R Programming

oxcgrt (version 0.1.0)

calculate_index: Calculate an OxCGRT index or indices

Description

Calculate an OxCGRT index or indices

Usage

calculate_index(df, codes, tolerance)

calculate_gov_response(df)

calculate_containment_health(df)

calculate_stringency(df)

calculate_economic_support(df)

calculate_indices(df)

Arguments

df

A data.frame produced by a call to calculate_subindices().

codes

A vector of policy type codes to use for the index calculation.

tolerance

An integer specifying the number of missing values above which index will not be calculated and reported.

Value

A numeric value for mean subindex scores of specified policy types. For calculate_indices(), a tibble calculated OxCGRT indices

Examples

Run this code
# NOT RUN {
## Get policy actions data for Afghanistan on 1 September 2020
x <- get_data(json = get_json_actions(ccode = "AFG",
                                      from = NULL,
                                      to = "2020-09-01"))

## Calculate OxCGRT subindices
y <- calculate_subindices(df = x$policyActions)

## Calculate OxCGRT index
calculate_index(df = y,
                codes = c(paste("C", 1:8, sep = ""),
                          paste("E", 1:2, sep = ""),
                          paste("H", 1:3, sep = ""), "H6"),
                tolerance = 1)

## Calculate OxCGRT government response index
calculate_gov_response(df = y)

## Calculate OxCGRT containment and health index
calculate_containment_health(df = y)

## Calculate OxCGRT stringency index
calculate_stringency(df = y)

## Calculate OxCGRT economic support index
calculate_economic_support(df = y)

## Calculate all OxCGRT indices
calculate_indices(df = y)

# }

Run the code above in your browser using DataLab